# AWS CDK CloudFormation Constructs for logzio::awsSecurityHub::collector::MODULE

Schema for Module Fragment of type logzio::awsSecurityHub::collector::MODULE

## License

Distributed under the Apache-2.0 License.
